@@ -75,14 +75,15 @@ class CONTAINER_IMAGES:
     RYU_1 = "csle_ryu_1"
     PENGINE_EXPLOIT_1 = "csle_pengine_exploit_1"
     CVE_2014_0160_1 = "csle_cve_2014_0160_1"
-    SNORT_IDS_IMAGES = ["csle_router_2"]
-    OVS_IMAGES = ["csle_ovs_1"]
-    OSSEC_IDS_IMAGES = ["csle_honeypot_1", "csle_honeypot_2", "csle_pengine_exploit_1", "csle_router_1",
-                        "csle_router_2", "csle_ssh_1", "csle_ssh_2",
-                        "csle_ssh_3", "csle_telnet_1", "csle_telnet_2", "csle_telnet_3"]
-    ROUTER_IMAGES = ["csle_router_1", "csle_router_2"]
-    HACKER_IMAGES = ["csle_hacker_kali_1"]
-    CLIENT_IMAGES = ["csle_client_1"]
+    SPARK_1 = "csle_spark_1"
+    SNORT_IDS_IMAGES = [ROUTER_2]
+    OVS_IMAGES = [OVS_1]
+    SPARK_IMAGES = [SPARK_1]
+    OSSEC_IDS_IMAGES = [HONEYPOT_1, HONEYPOT_2, PENGINE_EXPLOIT_1, ROUTER_1,
+                        ROUTER_2, SSH_1, SSH_2, SSH_3, TELNET_1, TELNET_2, TELNET_3, SPARK_1]
+    ROUTER_IMAGES = [ROUTER_1, ROUTER_2]
+    HACKER_IMAGES = [HACKER_KALI_1]
+    CLIENT_IMAGES = [CLIENT_1]
     CADVISOR = "cadvisor"
     PGADMIN = "pgadmin"
     GRAFANA = "grafana"
@@ -121,6 +122,7 @@ class CONTAINER_OS:
     FTP_2_OS = "ubuntu"
     PENGINE_EXPLOIT_1_OS = "ubuntu"
     CVE_2014_0160_1_OS = "debian"
+    SPARK_1_OS = "spark"
 
 
 class RENDERING:
@@ -652,13 +654,22 @@ class SNMP:
 
 class HTTP:
     """
-    Constants related to the DNS service
+    Constants related to the HTTP service
     """
     SERVICE_NAME = "http"
     DEFAULT_PORT = 80
     HTTP_PROTOCOL_PREFIX = "http://"
 
 
+class SPARK:
+    """
+    Constants related to the spark service
+    """
+    SERVICE_NAME = "spark"
+    DEFAULT_PORT = 7077
+    SPARK_PROTOCOL_PREFIX = "spark://"
+
+
 class DNS:
     """
     Constants related to the DNS service
@@ -1241,6 +1252,12 @@ class TRAFFIC_COMMANDS:
         f"{CONTAINER_IMAGES.CVE_2014_0160_1}": [
             "timeout 5 sshpass -p 'testcsleuser' ssh -oStrictHostKeyChecking=no {} > /dev/null 2>&1",
             "timeout 5 curl {}:443 > /dev/null 2>&1"],
+        f"{CONTAINER_IMAGES.SPARK_1}": [
+            "timeout 5 sshpass -p 'testcsleuser' ssh -oStrictHostKeyChecking=no {} > /dev/null 2>&1",
+            "timeout 5 curl {}:8080 > /dev/null 2>&1",
+            "timeout 5 curl {}:8081 > /dev/null 2>&1",
+            "/root/miniconda3/bin/python3 /spark_job.py --sparkmaster {} > /dev/null 2>&1"
+        ]
     }
 
 
