@@ -175,6 +175,20 @@ class EmulationDefenderMachineObservationState:
         with io.open(json_file_path, 'w', encoding='utf-8') as f:
             f.write(json_str)
 
+    @staticmethod
+    def from_json_file(json_file_path: str) -> "EmulationDefenderMachineObservationState":
+        """
+        Reads a json file and converts it to a DTO
+
+        :param json_file_path: the json file path
+        :return: the converted DTO
+        """
+        import io
+        import json
+        with io.open(json_file_path, 'r') as f:
+            json_str = f.read()
+        return EmulationDefenderMachineObservationState.from_dict(json.loads(json_str))
+
     def num_attributes(self) -> int:
         """
         :return: The number of attribute of the DTO
